@@ -1,21 +1,24 @@
-from typing import List
-from goyabucli.scraper import Scraper,Anime,bindScrapers
-from goyabucli.scrapers.goyabuNew import Goyabu
-from goyabucli.scrapers.animefire import AnimeFire
+from typing import List, Dict
+from .scraper import Scraper,Anime,bindScrapers
+from .scrapers.goyabuNew import Goyabu
+from .scrapers.animefire import AnimeFire
 
 SCRAPERS:List[Scraper] = [AnimeFire(), Goyabu()]
 
-
 class ScraperManager():
     def __init__(self):
         self.scrapers = SCRAPERS
-        self.animes = {
+        self.animes:Dict[str,Anime] = {
             # 'id1' : Anime('title', 'anime1')
         }
 
     @bindScrapers
-    def search(self, query:str) -> List[Anime]:
-        for scraper in self.scrapers:
+    def search(self, query:str, preferedScrapers=[]) -> List[Anime]:
+        scrapers = self.scrapers
+        if preferedScrapers:
+            scrapers = [scraper for scraper in self.scrapers if scraper.name in preferedScrapers]
+
+        for scraper in scrapers:
             for anime in scraper.search(query):
                 self._addAnime(anime)
 
